Learn R Programming

astrodatR (version 0.1)

asteroid_dens: Densities of asteroids

Description

This data set gives measured values for the physical density (in grams/cm^3) of 26 asteroids in the main Asteroid Belt of our Solar System, along with their measurement errors. This dataset is useful for analysis involving heteroscedastic measurement errors in 1-dimension, such as weighted density estimation and regression. Further description and references for the dataset are given in Appendix C.1 of Feigelson & Babu (2012).

Usage

asteroid_dens

Arguments

Format

A table containing 26 rows and 3 columns with header row.

Feigelson and Babu (2012)

References

Feigelson, E. D. and Babu, G. J. (2012) Modern Statistical Methods for Astronomy with R Applications, Cambridge UK:Cambridge University Press